<a id="mypy-boto3-iot"></a>

# mypy-boto3-iot

[![PyPI - mypy-boto3-iot](https://img.shields.io/pypi/v/mypy-boto3-iot.svg?color=blue)](https://pypi.org/project/mypy-boto3-iot)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-iot.svg?color=blue)](https://pypi.org/project/mypy-boto3-iot)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-iot?color=blue)](https://pypistats.org/packages/mypy-boto3-iot)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.IoT 1.25.5](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot.html#IoT)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.10](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-iot docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-iot](#mypy-boto3-iot)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `IoT`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `IoT` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[iot]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[iot]'


# standalone installation
python -m pip install mypy-boto3-iot
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-iot
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[iot]` in your environment:

```bash
python -m pip install 'boto3-stubs[iot]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[iot]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[iot]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[iot]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[iot]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[iot]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[iot]` in your environment:

```bash
python -m pip install 'boto3-stubs[iot]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[iot]` in your environment:

```bash
python -m pip install 'boto3-stubs[iot]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`IoTClient` provides annotations for `boto3.client("iot")`.

```python
from boto3.session import Session

from mypy_boto3_iot import IoTClient

client: IoTClient = Session().client("iot")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_iot.paginator` module contains type annotations for all paginators.

```python
from boto3.session import Session

from mypy_boto3_iot import IoTClient
from mypy_boto3_iot.paginator import (
    GetBehaviorModelTrainingSummariesPaginator,
    ListActiveViolationsPaginator,
    ListAttachedPoliciesPaginator,
    ListAuditFindingsPaginator,
    ListAuditMitigationActionsExecutionsPaginator,
    ListAuditMitigationActionsTasksPaginator,
    ListAuditSuppressionsPaginator,
    ListAuditTasksPaginator,
    ListAuthorizersPaginator,
    ListBillingGroupsPaginator,
    ListCACertificatesPaginator,
    ListCertificatesPaginator,
    ListCertificatesByCAPaginator,
    ListCustomMetricsPaginator,
    ListDetectMitigationActionsExecutionsPaginator,
    ListDetectMitigationActionsTasksPaginator,
    ListDimensionsPaginator,
    ListDomainConfigurationsPaginator,
    ListFleetMetricsPaginator,
    ListIndicesPaginator,
    ListJobExecutionsForJobPaginator,
    ListJobExecutionsForThingPaginator,
    ListJobTemplatesPaginator,
    ListJobsPaginator,
    ListMetricValuesPaginator,
    ListMitigationActionsPaginator,
    ListOTAUpdatesPaginator,
    ListOutgoingCertificatesPaginator,
    ListPoliciesPaginator,
    ListPolicyPrincipalsPaginator,
    ListPrincipalPoliciesPaginator,
    ListPrincipalThingsPaginator,
    ListProvisioningTemplateVersionsPaginator,
    ListProvisioningTemplatesPaginator,
    ListRoleAliasesPaginator,
    ListScheduledAuditsPaginator,
    ListSecurityProfilesPaginator,
    ListSecurityProfilesForTargetPaginator,
    ListStreamsPaginator,
    ListTagsForResourcePaginator,
    ListTargetsForPolicyPaginator,
    ListTargetsForSecurityProfilePaginator,
    ListThingGroupsPaginator,
    ListThingGroupsForThingPaginator,
    ListThingPrincipalsPaginator,
    ListThingRegistrationTaskReportsPaginator,
    ListThingRegistrationTasksPaginator,
    ListThingTypesPaginator,
    ListThingsPaginator,
    ListThingsInBillingGroupPaginator,
    ListThingsInThingGroupPaginator,
    ListTopicRuleDestinationsPaginator,
    ListTopicRulesPaginator,
    ListV2LoggingLevelsPaginator,
    ListViolationEventsPaginator,
)

client: IoTClient = Session().client("iot")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
get_behavior_model_training_summaries_paginator: GetBehaviorModelTrainingSummariesPaginator = (
    client.get_paginator("get_behavior_model_training_summaries")
)
list_active_violations_paginator: ListActiveViolationsPaginator = client.get_paginator(
    "list_active_violations"
)
list_attached_policies_paginator: ListAttachedPoliciesPaginator = client.get_paginator(
    "list_attached_policies"
)
list_audit_findings_paginator: ListAuditFindingsPaginator = client.get_paginator(
    "list_audit_findings"
)
list_audit_mitigation_actions_executions_paginator: ListAuditMitigationActionsExecutionsPaginator = client.get_paginator(
    "list_audit_mitigation_actions_executions"
)
list_audit_mitigation_actions_tasks_paginator: ListAuditMitigationActionsTasksPaginator = (
    client.get_paginator("list_audit_mitigation_actions_tasks")
)
list_audit_suppressions_paginator: ListAuditSuppressionsPaginator = client.get_paginator(
    "list_audit_suppressions"
)
list_audit_tasks_paginator: ListAuditTasksPaginator = client.get_paginator("list_audit_tasks")
list_authorizers_paginator: ListAuthorizersPaginator = client.get_paginator("list_authorizers")
list_billing_groups_paginator: ListBillingGroupsPaginator = client.get_paginator(
    "list_billing_groups"
)
list_ca_certificates_paginator: ListCACertificatesPaginator = client.get_paginator(
    "list_ca_certificates"
)
list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
list_certificates_by_ca_paginator: ListCertificatesByCAPaginator = client.get_paginator(
    "list_certificates_by_ca"
)
list_custom_metrics_paginator: ListCustomMetricsPaginator = client.get_paginator(
    "list_custom_metrics"
)
list_detect_mitigation_actions_executions_paginator: ListDetectMitigationActionsExecutionsPaginator = client.get_paginator(
    "list_detect_mitigation_actions_executions"
)
list_detect_mitigation_actions_tasks_paginator: ListDetectMitigationActionsTasksPaginator = (
    client.get_paginator("list_detect_mitigation_actions_tasks")
)
list_dimensions_paginator: ListDimensionsPaginator = client.get_paginator("list_dimensions")
list_domain_configurations_paginator: ListDomainConfigurationsPaginator = client.get_paginator(
    "list_domain_configurations"
)
list_fleet_metrics_paginator: ListFleetMetricsPaginator = client.get_paginator("list_fleet_metrics")
list_indices_paginator: ListIndicesPaginator = client.get_paginator("list_indices")
list_job_executions_for_job_paginator: ListJobExecutionsForJobPaginator = client.get_paginator(
    "list_job_executions_for_job"
)
list_job_executions_for_thing_paginator: ListJobExecutionsForThingPaginator = client.get_paginator(
    "list_job_executions_for_thing"
)
list_job_templates_paginator: ListJobTemplatesPaginator = client.get_paginator("list_job_templates")
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_metric_values_paginator: ListMetricValuesPaginator = client.get_paginator("list_metric_values")
list_mitigation_actions_paginator: ListMitigationActionsPaginator = client.get_paginator(
    "list_mitigation_actions"
)
list_ota_updates_paginator: ListOTAUpdatesPaginator = client.get_paginator("list_ota_updates")
list_outgoing_certificates_paginator: ListOutgoingCertificatesPaginator = client.get_paginator(
    "list_outgoing_certificates"
)
list_policies_paginator: ListPoliciesPaginator = client.get_paginator("list_policies")
list_policy_principals_paginator: ListPolicyPrincipalsPaginator = client.get_paginator(
    "list_policy_principals"
)
list_principal_policies_paginator: ListPrincipalPoliciesPaginator = client.get_paginator(
    "list_principal_policies"
)
list_principal_things_paginator: ListPrincipalThingsPaginator = client.get_paginator(
    "list_principal_things"
)
list_provisioning_template_versions_paginator: ListProvisioningTemplateVersionsPaginator = (
    client.get_paginator("list_provisioning_template_versions")
)
list_provisioning_templates_paginator: ListProvisioningTemplatesPaginator = client.get_paginator(
    "list_provisioning_templates"
)
list_role_aliases_paginator: ListRoleAliasesPaginator = client.get_paginator("list_role_aliases")
list_scheduled_audits_paginator: ListScheduledAuditsPaginator = client.get_paginator(
    "list_scheduled_audits"
)
list_security_profiles_paginator: ListSecurityProfilesPaginator = client.get_paginator(
    "list_security_profiles"
)
list_security_profiles_for_target_paginator: ListSecurityProfilesForTargetPaginator = (
    client.get_paginator("list_security_profiles_for_target")
)
list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator(
    "list_tags_for_resource"
)
list_targets_for_policy_paginator: ListTargetsForPolicyPaginator = client.get_paginator(
    "list_targets_for_policy"
)
list_targets_for_security_profile_paginator: ListTargetsForSecurityProfilePaginator = (
    client.get_paginator("list_targets_for_security_profile")
)
list_thing_groups_paginator: ListThingGroupsPaginator = client.get_paginator("list_thing_groups")
list_thing_groups_for_thing_paginator: ListThingGroupsForThingPaginator = client.get_paginator(
    "list_thing_groups_for_thing"
)
list_thing_principals_paginator: ListThingPrincipalsPaginator = client.get_paginator(
    "list_thing_principals"
)
list_thing_registration_task_reports_paginator: ListThingRegistrationTaskReportsPaginator = (
    client.get_paginator("list_thing_registration_task_reports")
)
list_thing_registration_tasks_paginator: ListThingRegistrationTasksPaginator = client.get_paginator(
    "list_thing_registration_tasks"
)
list_thing_types_paginator: ListThingTypesPaginator = client.get_paginator("list_thing_types")
list_things_paginator: ListThingsPaginator = client.get_paginator("list_things")
list_things_in_billing_group_paginator: ListThingsInBillingGroupPaginator = client.get_paginator(
    "list_things_in_billing_group"
)
list_things_in_thing_group_paginator: ListThingsInThingGroupPaginator = client.get_paginator(
    "list_things_in_thing_group"
)
list_topic_rule_destinations_paginator: ListTopicRuleDestinationsPaginator = client.get_paginator(
    "list_topic_rule_destinations"
)
list_topic_rules_paginator: ListTopicRulesPaginator = client.get_paginator("list_topic_rules")
list_v2_logging_levels_paginator: ListV2LoggingLevelsPaginator = client.get_paginator(
    "list_v2_logging_levels"
)
list_violation_events_paginator: ListViolationEventsPaginator = client.get_paginator(
    "list_violation_events"
)
```

<a id="literals"></a>

### Literals

`mypy_boto3_iot.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_iot.literals import (
    AbortActionType,
    ActionTypeType,
    AggregationTypeNameType,
    AlertTargetTypeType,
    AuditCheckRunStatusType,
    AuditFindingSeverityType,
    AuditFrequencyType,
    AuditMitigationActionsExecutionStatusType,
    AuditMitigationActionsTaskStatusType,
    AuditNotificationTypeType,
    AuditTaskStatusType,
    AuditTaskTypeType,
    AuthDecisionType,
    AuthorizerStatusType,
    AutoRegistrationStatusType,
    AwsJobAbortCriteriaAbortActionType,
    AwsJobAbortCriteriaFailureTypeType,
    BehaviorCriteriaTypeType,
    CACertificateStatusType,
    CACertificateUpdateActionType,
    CannedAccessControlListType,
    CertificateModeType,
    CertificateStatusType,
    ComparisonOperatorType,
    ConfidenceLevelType,
    CustomMetricTypeType,
    DayOfWeekType,
    DetectMitigationActionExecutionStatusType,
    DetectMitigationActionsTaskStatusType,
    DeviceCertificateUpdateActionType,
    DeviceDefenderIndexingModeType,
    DimensionTypeType,
    DimensionValueOperatorType,
    DomainConfigurationStatusType,
    DomainTypeType,
    DynamicGroupStatusType,
    DynamoKeyTypeType,
    EventTypeType,
    FieldTypeType,
    FleetMetricUnitType,
    GetBehaviorModelTrainingSummariesPaginatorName,
    IndexStatusType,
    JobExecutionFailureTypeType,
    JobExecutionStatusType,
    JobStatusType,
    ListActiveViolationsPaginatorName,
    ListAttachedPoliciesPaginatorName,
    ListAuditFindingsPaginatorName,
    ListAuditMitigationActionsExecutionsPaginatorName,
    ListAuditMitigationActionsTasksPaginatorName,
    ListAuditSuppressionsPaginatorName,
    ListAuditTasksPaginatorName,
    ListAuthorizersPaginatorName,
    ListBillingGroupsPaginatorName,
    ListCACertificatesPaginatorName,
    ListCertificatesByCAPaginatorName,
    ListCertificatesPaginatorName,
    ListCustomMetricsPaginatorName,
    ListDetectMitigationActionsExecutionsPaginatorName,
    ListDetectMitigationActionsTasksPaginatorName,
    ListDimensionsPaginatorName,
    ListDomainConfigurationsPaginatorName,
    ListFleetMetricsPaginatorName,
    ListIndicesPaginatorName,
    ListJobExecutionsForJobPaginatorName,
    ListJobExecutionsForThingPaginatorName,
    ListJobTemplatesPaginatorName,
    ListJobsPaginatorName,
    ListMetricValuesPaginatorName,
    ListMitigationActionsPaginatorName,
    ListOTAUpdatesPaginatorName,
    ListOutgoingCertificatesPaginatorName,
    ListPoliciesPaginatorName,
    ListPolicyPrincipalsPaginatorName,
    ListPrincipalPoliciesPaginatorName,
    ListPrincipalThingsPaginatorName,
    ListProvisioningTemplateVersionsPaginatorName,
    ListProvisioningTemplatesPaginatorName,
    ListRoleAliasesPaginatorName,
    ListScheduledAuditsPaginatorName,
    ListSecurityProfilesForTargetPaginatorName,
    ListSecurityProfilesPaginatorName,
    ListStreamsPaginatorName,
    ListTagsForResourcePaginatorName,
    ListTargetsForPolicyPaginatorName,
    ListTargetsForSecurityProfilePaginatorName,
    ListThingGroupsForThingPaginatorName,
    ListThingGroupsPaginatorName,
    ListThingPrincipalsPaginatorName,
    ListThingRegistrationTaskReportsPaginatorName,
    ListThingRegistrationTasksPaginatorName,
    ListThingTypesPaginatorName,
    ListThingsInBillingGroupPaginatorName,
    ListThingsInThingGroupPaginatorName,
    ListThingsPaginatorName,
    ListTopicRuleDestinationsPaginatorName,
    ListTopicRulesPaginatorName,
    ListV2LoggingLevelsPaginatorName,
    ListViolationEventsPaginatorName,
    LogLevelType,
    LogTargetTypeType,
    MessageFormatType,
    MitigationActionTypeType,
    ModelStatusType,
    NamedShadowIndexingModeType,
    OTAUpdateStatusType,
    PolicyTemplateNameType,
    ProtocolType,
    ReportTypeType,
    ResourceTypeType,
    RetryableFailureTypeType,
    ServerCertificateStatusType,
    ServiceTypeType,
    StatusType,
    TargetSelectionType,
    TemplateTypeType,
    ThingConnectivityIndexingModeType,
    ThingGroupIndexingModeType,
    ThingIndexingModeType,
    TopicRuleDestinationStatusType,
    VerificationStateType,
    ViolationEventTypeType,
    IoTServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AbortActionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_iot.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_iot.type_defs import (
    AbortCriteriaTypeDef,
    AcceptCertificateTransferRequestRequestTypeDef,
    CloudwatchAlarmActionTypeDef,
    CloudwatchLogsActionTypeDef,
    CloudwatchMetricActionTypeDef,
    DynamoDBActionTypeDef,
    ElasticsearchActionTypeDef,
    FirehoseActionTypeDef,
    IotAnalyticsActionTypeDef,
    IotEventsActionTypeDef,
    KafkaActionTypeDef,
    KinesisActionTypeDef,
    LambdaActionTypeDef,
    OpenSearchActionTypeDef,
    RepublishActionTypeDef,
    S3ActionTypeDef,
    SalesforceActionTypeDef,
    SnsActionTypeDef,
    SqsActionTypeDef,
    StepFunctionsActionTypeDef,
    MetricValueTypeDef,
    ViolationEventAdditionalInfoTypeDef,
    AddThingToBillingGroupRequestRequestTypeDef,
    AddThingToThingGroupRequestRequestTypeDef,
    AddThingsToThingGroupParamsTypeDef,
    AggregationTypeTypeDef,
    AlertTargetTypeDef,
    PolicyTypeDef,
    AssetPropertyTimestampTypeDef,
    AssetPropertyVariantTypeDef,
    AssociateTargetsWithJobRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    AttachPolicyRequestRequestTypeDef,
    AttachPrincipalPolicyRequestRequestTypeDef,
    AttachSecurityProfileRequestRequestTypeDef,
    AttachThingPrincipalRequestRequestTypeDef,
    AttributePayloadTypeDef,
    AuditCheckConfigurationTypeDef,
    AuditCheckDetailsTypeDef,
    AuditMitigationActionExecutionMetadataTypeDef,
    AuditMitigationActionsTaskMetadataTypeDef,
    AuditMitigationActionsTaskTargetTypeDef,
    AuditNotificationTargetTypeDef,
    AuditTaskMetadataTypeDef,
    AuthInfoTypeDef,
    AuthorizerConfigTypeDef,
    AuthorizerDescriptionTypeDef,
    AuthorizerSummaryTypeDef,
    AwsJobAbortCriteriaTypeDef,
    AwsJobRateIncreaseCriteriaTypeDef,
    AwsJobPresignedUrlConfigTypeDef,
    AwsJobTimeoutConfigTypeDef,
    MachineLearningDetectionConfigTypeDef,
    StatisticalThresholdTypeDef,
    BehaviorModelTrainingSummaryTypeDef,
    MetricDimensionTypeDef,
    BillingGroupMetadataTypeDef,
    BillingGroupPropertiesTypeDef,
    BucketTypeDef,
    TermsAggregationTypeDef,
    CertificateValidityTypeDef,
    CACertificateTypeDef,
    CancelAuditMitigationActionsTaskRequestRequestTypeDef,
    CancelAuditTaskRequestRequestTypeDef,
    CancelCertificateTransferRequestRequestTypeDef,
    CancelDetectMitigationActionsTaskRequestRequestTypeDef,
    CancelJobExecutionRequestRequestTypeDef,
    CancelJobRequestRequestTypeDef,
    TransferDataTypeDef,
    CertificateTypeDef,
    CodeSigningCertificateChainTypeDef,
    CodeSigningSignatureTypeDef,
    ConfigurationTypeDef,
    ConfirmTopicRuleDestinationRequestRequestTypeDef,
    TagTypeDef,
    CreateCertificateFromCsrRequestRequestTypeDef,
    PresignedUrlConfigTypeDef,
    TimeoutConfigTypeDef,
    CreateKeysAndCertificateRequestRequestTypeDef,
    KeyPairTypeDef,
    CreatePolicyVersionRequestRequestTypeDef,
    CreateProvisioningClaimRequestRequestTypeDef,
    ProvisioningHookTypeDef,
    CreateProvisioningTemplateVersionRequestRequestTypeDef,
    ThingTypePropertiesTypeDef,
    DeleteAccountAuditConfigurationRequestRequestTypeDef,
    DeleteAuthorizerRequestRequestTypeDef,
    DeleteBillingGroupRequestRequestTypeDef,
    DeleteCACertificateRequestRequestTypeDef,
    DeleteCertificateRequestRequestTypeDef,
    DeleteCustomMetricRequestRequestTypeDef,
    DeleteDimensionRequestRequestTypeDef,
    DeleteDomainConfigurationRequestRequestTypeDef,
    DeleteDynamicThingGroupRequestRequestTypeDef,
    DeleteFleetMetricRequestRequestTypeDef,
    DeleteJobExecutionRequestRequestTypeDef,
    DeleteJobRequestRequestTypeDef,
    DeleteJobTemplateRequestRequestTypeDef,
    DeleteMitigationActionRequestRequestTypeDef,
    DeleteOTAUpdateRequestRequestTypeDef,
    DeletePolicyRequestRequestTypeDef,
    DeletePolicyVersionRequestRequestTypeDef,
    DeleteProvisioningTemplateRequestRequestTypeDef,
    DeleteProvisioningTemplateVersionRequestRequestTypeDef,
    DeleteRoleAliasRequestRequestTypeDef,
    DeleteScheduledAuditRequestRequestTypeDef,
    DeleteSecurityProfileRequestRequestTypeDef,
    DeleteStreamRequestRequestTypeDef,
    DeleteThingGroupRequestRequestTypeDef,
    DeleteThingRequestRequestTypeDef,
    DeleteThingTypeRequestRequestTypeDef,
    DeleteTopicRuleDestinationRequestRequestTypeDef,
    DeleteTopicRuleRequestRequestTypeDef,
    DeleteV2LoggingLevelRequestRequestTypeDef,
    DeprecateThingTypeRequestRequestTypeDef,
    DescribeAuditFindingRequestRequestTypeDef,
    DescribeAuditMitigationActionsTaskRequestRequestTypeDef,
    TaskStatisticsForAuditCheckTypeDef,
    DescribeAuditTaskRequestRequestTypeDef,
    TaskStatisticsTypeDef,
    DescribeAuthorizerRequestRequestTypeDef,
    DescribeBillingGroupRequestRequestTypeDef,
    DescribeCACertificateRequestRequestTypeDef,
    RegistrationConfigTypeDef,
    DescribeCertificateRequestRequestTypeDef,
    DescribeCustomMetricRequestRequestTypeDef,
    DescribeDetectMitigationActionsTaskRequestRequestTypeDef,
    DescribeDimensionRequestRequestTypeDef,
    DescribeDomainConfigurationRequestRequestTypeDef,
    ServerCertificateSummaryTypeDef,
    DescribeEndpointRequestRequestTypeDef,
    DescribeFleetMetricRequestRequestTypeDef,
    DescribeIndexRequestRequestTypeDef,
    DescribeJobExecutionRequestRequestTypeDef,
    DescribeJobRequestRequestTypeDef,
    DescribeJobTemplateRequestRequestTypeDef,
    DescribeManagedJobTemplateRequestRequestTypeDef,
    DocumentParameterTypeDef,
    DescribeMitigationActionRequestRequestTypeDef,
    DescribeProvisioningTemplateRequestRequestTypeDef,
    DescribeProvisioningTemplateVersionRequestRequestTypeDef,
    DescribeRoleAliasRequestRequestTypeDef,
    RoleAliasDescriptionTypeDef,
    DescribeScheduledAuditRequestRequestTypeDef,
    DescribeSecurityProfileRequestRequestTypeDef,
    DescribeStreamRequestRequestTypeDef,
    DescribeThingGroupRequestRequestTypeDef,
    DescribeThingRegistrationTaskRequestRequestTypeDef,
    DescribeThingRequestRequestTypeDef,
    DescribeThingTypeRequestRequestTypeDef,
    ThingTypeMetadataTypeDef,
    S3DestinationTypeDef,
    DetachPolicyRequestRequestTypeDef,
    DetachPrincipalPolicyRequestRequestTypeDef,
    DetachSecurityProfileRequestRequestTypeDef,
    DetachThingPrincipalRequestRequestTypeDef,
    DetectMitigationActionExecutionTypeDef,
    DetectMitigationActionsTaskStatisticsTypeDef,
    DetectMitigationActionsTaskTargetTypeDef,
    ViolationEventOccurrenceRangeTypeDef,
    DisableTopicRuleRequestRequestTypeDef,
    DomainConfigurationSummaryTypeDef,
    PutItemInputTypeDef,
    EffectivePolicyTypeDef,
    EnableIoTLoggingParamsTypeDef,
    EnableTopicRuleRequestRequestTypeDef,
    ErrorInfoTypeDef,
    RateIncreaseCriteriaTypeDef,
    FieldTypeDef,
    S3LocationTypeDef,
    StreamTypeDef,
    FleetMetricNameAndArnTypeDef,
    PaginatorConfigTypeDef,
    GetBehaviorModelTrainingSummariesRequestRequestTypeDef,
    GetCardinalityRequestRequestTypeDef,
    GetEffectivePoliciesRequestRequestTypeDef,
    GetJobDocumentRequestRequestTypeDef,
    GetOTAUpdateRequestRequestTypeDef,
    GetPercentilesRequestRequestTypeDef,
    PercentPairTypeDef,
    GetPolicyRequestRequestTypeDef,
    GetPolicyVersionRequestRequestTypeDef,
    GetStatisticsRequestRequestTypeDef,
    StatisticsTypeDef,
    GetTopicRuleDestinationRequestRequestTypeDef,
    GetTopicRuleRequestRequestTypeDef,
    GroupNameAndArnTypeDef,
    HttpActionHeaderTypeDef,
    SigV4AuthorizationTypeDef,
    HttpContextTypeDef,
    HttpUrlDestinationConfigurationTypeDef,
    HttpUrlDestinationPropertiesTypeDef,
    HttpUrlDestinationSummaryTypeDef,
    IndexingFilterTypeDef,
    JobExecutionStatusDetailsTypeDef,
    JobExecutionSummaryTypeDef,
    RetryCriteriaTypeDef,
    JobProcessDetailsTypeDef,
    JobSummaryTypeDef,
    JobTemplateSummaryTypeDef,
    ListActiveViolationsRequestRequestTypeDef,
    ListAttachedPoliciesRequestRequestTypeDef,
    ListAuditMitigationActionsExecutionsRequestRequestTypeDef,
    ListAuditMitigationActionsTasksRequestRequestTypeDef,
    ListAuditTasksRequestRequestTypeDef,
    ListAuthorizersRequestRequestTypeDef,
    ListBillingGroupsRequestRequestTypeDef,
    ListCACertificatesRequestRequestTypeDef,
    ListCertificatesByCARequestRequestTypeDef,
    ListCertificatesRequestRequestTypeDef,
    ListCustomMetricsRequestRequestTypeDef,
    ListDetectMitigationActionsExecutionsRequestRequestTypeDef,
    ListDetectMitigationActionsTasksRequestRequestTypeDef,
    ListDimensionsRequestRequestTypeDef,
    ListDomainConfigurationsRequestRequestTypeDef,
    ListFleetMetricsRequestRequestTypeDef,
    ListIndicesRequestRequestTypeDef,
    ListJobExecutionsForJobRequestRequestTypeDef,
    ListJobExecutionsForThingRequestRequestTypeDef,
    ListJobTemplatesRequestRequestTypeDef,
    ListJobsRequestRequestTypeDef,
    ListManagedJobTemplatesRequestRequestTypeDef,
    ManagedJobTemplateSummaryTypeDef,
    ListMetricValuesRequestRequestTypeDef,
    ListMitigationActionsRequestRequestTypeDef,
    MitigationActionIdentifierTypeDef,
    ListOTAUpdatesRequestRequestTypeDef,
    OTAUpdateSummaryTypeDef,
    ListOutgoingCertificatesRequestRequestTypeDef,
    OutgoingCertificateTypeDef,
    ListPoliciesRequestRequestTypeDef,
    ListPolicyPrincipalsRequestRequestTypeDef,
    ListPolicyVersionsRequestRequestTypeDef,
    PolicyVersionTypeDef,
    ListPrincipalPoliciesRequestRequestTypeDef,
    ListPrincipalThingsRequestRequestTypeDef,
    ListProvisioningTemplateVersionsRequestRequestTypeDef,
    ProvisioningTemplateVersionSummaryTypeDef,
    ListProvisioningTemplatesRequestRequestTypeDef,
    ProvisioningTemplateSummaryTypeDef,
    ListRoleAliasesRequestRequestTypeDef,
    ListScheduledAuditsRequestRequestTypeDef,
    ScheduledAuditMetadataTypeDef,
    ListSecurityProfilesForTargetRequestRequestTypeDef,
    ListSecurityProfilesRequestRequestTypeDef,
    SecurityProfileIdentifierTypeDef,
    ListStreamsRequestRequestTypeDef,
    StreamSummaryTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTargetsForPolicyRequestRequestTypeDef,
    ListTargetsForSecurityProfileRequestRequestTypeDef,
    SecurityProfileTargetTypeDef,
    ListThingGroupsForThingRequestRequestTypeDef,
    ListThingGroupsRequestRequestTypeDef,
    ListThingPrincipalsRequestRequestTypeDef,
    ListThingRegistrationTaskReportsRequestRequestTypeDef,
    ListThingRegistrationTasksRequestRequestTypeDef,
    ListThingTypesRequestRequestTypeDef,
    ListThingsInBillingGroupRequestRequestTypeDef,
    ListThingsInThingGroupRequestRequestTypeDef,
    ListThingsRequestRequestTypeDef,
    ThingAttributeTypeDef,
    ListTopicRuleDestinationsRequestRequestTypeDef,
    ListTopicRulesRequestRequestTypeDef,
    TopicRuleListItemTypeDef,
    ListV2LoggingLevelsRequestRequestTypeDef,
    ListViolationEventsRequestRequestTypeDef,
    LocationTimestampTypeDef,
    LogTargetTypeDef,
    LoggingOptionsPayloadTypeDef,
    PublishFindingToSnsParamsTypeDef,
    ReplaceDefaultPolicyVersionParamsTypeDef,
    UpdateCACertificateParamsTypeDef,
    UpdateDeviceCertificateParamsTypeDef,
    MqttContextTypeDef,
    PolicyVersionIdentifierTypeDef,
    PutVerificationStateOnViolationRequestRequestTypeDef,
    RegisterCertificateRequestRequestTypeDef,
    RegisterCertificateWithoutCARequestRequestTypeDef,
    RegisterThingRequestRequestTypeDef,
    RejectCertificateTransferRequestRequestTypeDef,
    RemoveThingFromBillingGroupRequestRequestTypeDef,
    RemoveThingFromThingGroupRequestRequestTypeDef,
    SearchIndexRequestRequestTypeDef,
    ThingGroupDocumentTypeDef,
    SetDefaultAuthorizerRequestRequestTypeDef,
    SetDefaultPolicyVersionRequestRequestTypeDef,
    SetV2LoggingOptionsRequestRequestTypeDef,
    SigningProfileParameterTypeDef,
    StartOnDemandAuditTaskRequestRequestTypeDef,
    StartThingRegistrationTaskRequestRequestTypeDef,
    StopThingRegistrationTaskRequestRequestTypeDef,
    TlsContextTypeDef,
    ThingConnectivityTypeDef,
    TimestreamDimensionTypeDef,
    TimestreamTimestampTypeDef,
    VpcDestinationConfigurationTypeDef,
    VpcDestinationSummaryTypeDef,
    VpcDestinationPropertiesTypeDef,
    TransferCertificateRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAuthorizerRequestRequestTypeDef,
    UpdateCertificateRequestRequestTypeDef,
    UpdateCustomMetricRequestRequestTypeDef,
    UpdateDimensionRequestRequestTypeDef,
    UpdateRoleAliasRequestRequestTypeDef,
    UpdateScheduledAuditRequestRequestTypeDef,
    UpdateThingGroupsForThingRequestRequestTypeDef,
    UpdateTopicRuleDestinationRequestRequestTypeDef,
    ValidationErrorTypeDef,
    AbortConfigTypeDef,
    MetricDatumTypeDef,
    UpdateFleetMetricRequestRequestTypeDef,
    AllowedTypeDef,
    ExplicitDenyTypeDef,
    ImplicitDenyTypeDef,
    AssetPropertyValueTypeDef,
    AssociateTargetsWithJobResponseTypeDef,
    CancelJobResponseTypeDef,
    CreateAuthorizerResponseTypeDef,
    CreateBillingGroupResponseTypeDef,
    CreateCertificateFromCsrResponseTypeDef,
    CreateCustomMetricResponseTypeDef,
    CreateDimensionResponseTypeDef,
    CreateDomainConfigurationResponseTypeDef,
    CreateDynamicThingGroupResponseTypeDef,
    CreateFleetMetricResponseTypeDef,
    CreateJobResponseTypeDef,
    CreateJobTemplateResponseTypeDef,
    CreateMitigationActionResponseTypeDef,
    CreateOTAUpdateResponseTypeDef,
    CreatePolicyResponseTypeDef,
    CreatePolicyVersionResponseTypeDef,
    CreateProvisioningTemplateResponseTypeDef,
    CreateProvisioningTemplateVersionResponseTypeDef,
    CreateRoleAliasResponseTypeDef,
    CreateScheduledAuditResponseTypeDef,
    CreateSecurityProfileResponseTypeDef,
    CreateStreamResponseTypeDef,
    CreateThingGroupResponseTypeDef,
    CreateThingResponseTypeDef,
    CreateThingTypeResponseTypeDef,
    DescribeCustomMetricResponseTypeDef,
    DescribeDimensionResponseTypeDef,
    DescribeEndpointResponseTypeDef,
    DescribeFleetMetricResponseTypeDef,
    DescribeIndexResponseTypeDef,
    DescribeProvisioningTemplateVersionResponseTypeDef,
    DescribeScheduledAuditResponseTypeDef,
    DescribeThingRegistrationTaskResponseTypeDef,
    DescribeThingResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    GetCardinalityResponseTypeDef,
    GetJobDocumentResponseTypeDef,
    GetLoggingOptionsResponseTypeDef,
    GetPolicyResponseTypeDef,
    GetPolicyVersionResponseTypeDef,
    GetRegistrationCodeResponseTypeDef,
    GetV2LoggingOptionsResponseTypeDef,
    ListAttachedPoliciesResponseTypeDef,
    ListCustomMetricsResponseTypeDef,
    ListDimensionsResponseTypeDef,
    ListIndicesResponseTypeDef,
    ListPoliciesResponseTypeDef,
    ListPolicyPrincipalsResponseTypeDef,
    ListPrincipalPoliciesResponseTypeDef,
    ListPrincipalThingsResponseTypeDef,
    ListRoleAliasesResponseTypeDef,
    ListTargetsForPolicyResponseTypeDef,
    ListThingPrincipalsResponseTypeDef,
    ListThingRegistrationTaskReportsResponseTypeDef,
    ListThingRegistrationTasksResponseTypeDef,
    ListThingsInBillingGroupResponseTypeDef,
    ListThingsInThingGroupResponseTypeDef,
    RegisterCACertificateResponseTypeDef,
    RegisterCertificateResponseTypeDef,
    RegisterCertificateWithoutCAResponseTypeDef,
    RegisterThingResponseTypeDef,
    SetDefaultAuthorizerResponseTypeDef,
    StartAuditMitigationActionsTaskResponseTypeDef,
    StartDetectMitigationActionsTaskResponseTypeDef,
    StartOnDemandAuditTaskResponseTypeDef,
    StartThingRegistrationTaskResponseTypeDef,
    TestInvokeAuthorizerResponseTypeDef,
    TransferCertificateResponseTypeDef,
    UpdateAuthorizerResponseTypeDef,
    UpdateBillingGroupResponseTypeDef,
    UpdateCustomMetricResponseTypeDef,
    UpdateDimensionResponseTypeDef,
    UpdateDomainConfigurationResponseTypeDef,
    UpdateDynamicThingGroupResponseTypeDef,
    UpdateMitigationActionResponseTypeDef,
    UpdateRoleAliasResponseTypeDef,
    UpdateScheduledAuditResponseTypeDef,
    UpdateStreamResponseTypeDef,
    UpdateThingGroupResponseTypeDef,
    CreateThingRequestRequestTypeDef,
    ThingGroupPropertiesTypeDef,
    UpdateThingRequestRequestTypeDef,
    ListAuditMitigationActionsExecutionsResponseTypeDef,
    ListAuditMitigationActionsTasksResponseTypeDef,
    StartAuditMitigationActionsTaskRequestRequestTypeDef,
    DescribeAccountAuditConfigurationResponseTypeDef,
    UpdateAccountAuditConfigurationRequestRequestTypeDef,
    ListAuditTasksResponseTypeDef,
    TestAuthorizationRequestRequestTypeDef,
    UpdateDomainConfigurationRequestRequestTypeDef,
    DescribeAuthorizerResponseTypeDef,
    DescribeDefaultAuthorizerResponseTypeDef,
    ListAuthorizersResponseTypeDef,
    AwsJobAbortConfigTypeDef,
    AwsJobExponentialRolloutRateTypeDef,
    BehaviorCriteriaTypeDef,
    GetBehaviorModelTrainingSummariesResponseTypeDef,
    MetricToRetainTypeDef,
    DescribeBillingGroupResponseTypeDef,
    UpdateBillingGroupRequestRequestTypeDef,
    GetBucketsAggregationResponseTypeDef,
    BucketsAggregationTypeTypeDef,
    CACertificateDescriptionTypeDef,
    ListCACertificatesResponseTypeDef,
    CertificateDescriptionTypeDef,
    ListCertificatesByCAResponseTypeDef,
    ListCertificatesResponseTypeDef,
    CustomCodeSigningTypeDef,
    DescribeEventConfigurationsResponseTypeDef,
    UpdateEventConfigurationsRequestRequestTypeDef,
    CreateAuthorizerRequestRequestTypeDef,
    CreateBillingGroupRequestRequestTypeDef,
    CreateCustomMetricRequestRequestTypeDef,
    CreateDimensionRequestRequestTypeDef,
    CreateDomainConfigurationRequestRequestTypeDef,
    CreateFleetMetricRequestRequestTypeDef,
    CreatePolicyRequestRequestTypeDef,
    CreateRoleAliasRequestRequestTypeDef,
    CreateScheduledAuditRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    CreateKeysAndCertificateResponseTypeDef,
    CreateProvisioningClaimResponseTypeDef,
    CreateProvisioningTemplateRequestRequestTypeDef,
    DescribeProvisioningTemplateResponseTypeDef,
    UpdateProvisioningTemplateRequestRequestTypeDef,
    CreateThingTypeRequestRequestTypeDef,
    DescribeAuditTaskResponseTypeDef,
    RegisterCACertificateRequestRequestTypeDef,
    UpdateCACertificateRequestRequestTypeDef,
    DescribeDomainConfigurationResponseTypeDef,
    DescribeManagedJobTemplateResponseTypeDef,
    DescribeRoleAliasResponseTypeDef,
    DescribeThingTypeResponseTypeDef,
    ThingTypeDefinitionTypeDef,
    DestinationTypeDef,
    ListDetectMitigationActionsExecutionsResponseTypeDef,
    StartDetectMitigationActionsTaskRequestRequestTypeDef,
    ListDomainConfigurationsResponseTypeDef,
    DynamoDBv2ActionTypeDef,
    GetEffectivePoliciesResponseTypeDef,
    ExponentialRolloutRateTypeDef,
    ThingGroupIndexingConfigurationTypeDef,
    StreamFileTypeDef,
    FileLocationTypeDef,
    ListFleetMetricsResponseTypeDef,
    GetBehaviorModelTrainingSummariesRequestGetBehaviorModelTrainingSummariesPaginateTypeDef,
    ListActiveViolationsRequestListActiveViolationsPaginateTypeDef,
    ListAttachedPoliciesRequestListAttachedPoliciesPaginateTypeDef,
    ListAuditMitigationActionsExecutionsRequestListAuditMitigationActionsExecutionsPaginateTypeDef,
    ListAuditMitigationActionsTasksRequestListAuditMitigationActionsTasksPaginateTypeDef,
    ListAuditTasksRequestListAuditTasksPaginateTypeDef,
    ListAuthorizersRequestListAuthorizersPaginateTypeDef,
    ListBillingGroupsRequestListBillingGroupsPaginateTypeDef,
    ListCACertificatesRequestListCACertificatesPaginateTypeDef,
    ListCertificatesByCARequestListCertificatesByCAPaginateTypeDef,
    ListCertificatesRequestListCertificatesPaginateTypeDef,
    ListCustomMetricsRequestListCustomMetricsPaginateTypeDef,
    ListDetectMitigationActionsExecutionsRequestListDetectMitigationActionsExecutionsPaginateTypeDef,
    ListDetectMitigationActionsTasksRequestListDetectMitigationActionsTasksPaginateTypeDef,
    ListDimensionsRequestListDimensionsPaginateTypeDef,
    ListDomainConfigurationsRequestListDomainConfigurationsPaginateTypeDef,
    ListFleetMetricsRequestListFleetMetricsPaginateTypeDef,
    ListIndicesRequestListIndicesPaginateTypeDef,
    ListJobExecutionsForJobRequestListJobExecutionsForJobPaginateTypeDef,
    ListJobExecutionsForThingRequestListJobExecutionsForThingPaginateTypeDef,
    ListJobTemplatesRequestListJobTemplatesPaginateTypeDef,
    ListJobsRequestListJobsPaginateTypeDef,
    ListMetricValuesRequestListMetricValuesPaginateTypeDef,
    ListMitigationActionsRequestListMitigationActionsPaginateTypeDef,
    ListOTAUpdatesRequestListOTAUpdatesPaginateTypeDef,
    ListOutgoingCertificatesRequestListOutgoingCertificatesPaginateTypeDef,
    ListPoliciesRequestListPoliciesPaginateTypeDef,
    ListPolicyPrincipalsRequestListPolicyPrincipalsPaginateTypeDef,
    ListPrincipalPoliciesRequestListPrincipalPoliciesPaginateTypeDef,
    ListPrincipalThingsRequestListPrincipalThingsPaginateTypeDef,
    ListProvisioningTemplateVersionsRequestListProvisioningTemplateVersionsPaginateTypeDef,
    ListProvisioningTemplatesRequestListProvisioningTemplatesPaginateTypeDef,
    ListRoleAliasesRequestListRoleAliasesPaginateTypeDef,
    ListScheduledAuditsRequestListScheduledAuditsPaginateTypeDef,
    ListSecurityProfilesForTargetRequestListSecurityProfilesForTargetPaginateTypeDef,
    ListSecurityProfilesRequestListSecurityProfilesPaginateTypeDef,
    ListStreamsRequestListStreamsPaginateTypeDef,
    ListTagsForResourceRequestListTagsForResourcePaginateTypeDef,
    ListTargetsForPolicyRequestListTargetsForPolicyPaginateTypeDef,
    ListTargetsForSecurityProfileRequestListTargetsForSecurityProfilePaginateTypeDef,
    ListThingGroupsForThingRequestListThingGroupsForThingPaginateTypeDef,
    ListThingGroupsRequestListThingGroupsPaginateTypeDef,
    ListThingPrincipalsRequestListThingPrincipalsPaginateTypeDef,
    ListThingRegistrationTaskReportsRequestListThingRegistrationTaskReportsPaginateTypeDef,
    ListThingRegistrationTasksRequestListThingRegistrationTasksPaginateTypeDef,
    ListThingTypesRequestListThingTypesPaginateTypeDef,
    ListThingsInBillingGroupRequestListThingsInBillingGroupPaginateTypeDef,
    ListThingsInThingGroupRequestListThingsInThingGroupPaginateTypeDef,
    ListThingsRequestListThingsPaginateTypeDef,
    ListTopicRuleDestinationsRequestListTopicRuleDestinationsPaginateTypeDef,
    ListTopicRulesRequestListTopicRulesPaginateTypeDef,
    ListV2LoggingLevelsRequestListV2LoggingLevelsPaginateTypeDef,
    ListViolationEventsRequestListViolationEventsPaginateTypeDef,
    GetPercentilesResponseTypeDef,
    GetStatisticsResponseTypeDef,
    ListBillingGroupsResponseTypeDef,
    ListThingGroupsForThingResponseTypeDef,
    ListThingGroupsResponseTypeDef,
    ThingGroupMetadataTypeDef,
    HttpAuthorizationTypeDef,
    ThingIndexingConfigurationTypeDef,
    JobExecutionTypeDef,
    JobExecutionSummaryForJobTypeDef,
    JobExecutionSummaryForThingTypeDef,
    JobExecutionsRetryConfigTypeDef,
    ListJobsResponseTypeDef,
    ListJobTemplatesResponseTypeDef,
    ListManagedJobTemplatesResponseTypeDef,
    ListMitigationActionsResponseTypeDef,
    ListOTAUpdatesResponseTypeDef,
    ListOutgoingCertificatesResponseTypeDef,
    ListPolicyVersionsResponseTypeDef,
    ListProvisioningTemplateVersionsResponseTypeDef,
    ListProvisioningTemplatesResponseTypeDef,
    ListScheduledAuditsResponseTypeDef,
    ListSecurityProfilesResponseTypeDef,
    ListStreamsResponseTypeDef,
    ListTargetsForSecurityProfileResponseTypeDef,
    SecurityProfileTargetMappingTypeDef,
    ListThingsResponseTypeDef,
    ListTopicRulesResponseTypeDef,
    LocationActionTypeDef,
    LogTargetConfigurationTypeDef,
    SetV2LoggingLevelRequestRequestTypeDef,
    SetLoggingOptionsRequestRequestTypeDef,
    MitigationActionParamsTypeDef,
    ResourceIdentifierTypeDef,
    TestInvokeAuthorizerRequestRequestTypeDef,
    ThingDocumentTypeDef,
    TimestreamActionTypeDef,
    TopicRuleDestinationConfigurationTypeDef,
    TopicRuleDestinationSummaryTypeDef,
    TopicRuleDestinationTypeDef,
    ValidateSecurityProfileBehaviorsResponseTypeDef,
    ListMetricValuesResponseTypeDef,
    DeniedTypeDef,
    PutAssetPropertyValueEntryTypeDef,
    CreateDynamicThingGroupRequestRequestTypeDef,
    CreateThingGroupRequestRequestTypeDef,
    UpdateDynamicThingGroupRequestRequestTypeDef,
    UpdateThingGroupRequestRequestTypeDef,
    AwsJobExecutionsRolloutConfigTypeDef,
    BehaviorTypeDef,
    GetBucketsAggregationRequestRequestTypeDef,
    DescribeCACertificateResponseTypeDef,
    DescribeCertificateResponseTypeDef,
    ListThingTypesResponseTypeDef,
    StartSigningJobParameterTypeDef,
    JobExecutionsRolloutConfigTypeDef,
    CreateStreamRequestRequestTypeDef,
    StreamInfoTypeDef,
    UpdateStreamRequestRequestTypeDef,
    DescribeThingGroupResponseTypeDef,
    HttpActionTypeDef,
    GetIndexingConfigurationResponseTypeDef,
    UpdateIndexingConfigurationRequestRequestTypeDef,
    DescribeJobExecutionResponseTypeDef,
    ListJobExecutionsForJobResponseTypeDef,
    ListJobExecutionsForThingResponseTypeDef,
    ListSecurityProfilesForTargetResponseTypeDef,
    ListV2LoggingLevelsResponseTypeDef,
    CreateMitigationActionRequestRequestTypeDef,
    DescribeMitigationActionResponseTypeDef,
    MitigationActionTypeDef,
    UpdateMitigationActionRequestRequestTypeDef,
    AuditSuppressionTypeDef,
    CreateAuditSuppressionRequestRequestTypeDef,
    DeleteAuditSuppressionRequestRequestTypeDef,
    DescribeAuditSuppressionRequestRequestTypeDef,
    DescribeAuditSuppressionResponseTypeDef,
    ListAuditFindingsRequestListAuditFindingsPaginateTypeDef,
    ListAuditFindingsRequestRequestTypeDef,
    ListAuditSuppressionsRequestListAuditSuppressionsPaginateTypeDef,
    ListAuditSuppressionsRequestRequestTypeDef,
    NonCompliantResourceTypeDef,
    RelatedResourceTypeDef,
    UpdateAuditSuppressionRequestRequestTypeDef,
    SearchIndexResponseTypeDef,
    CreateTopicRuleDestinationRequestRequestTypeDef,
    ListTopicRuleDestinationsResponseTypeDef,
    CreateTopicRuleDestinationResponseTypeDef,
    GetTopicRuleDestinationResponseTypeDef,
    AuthResultTypeDef,
    IotSiteWiseActionTypeDef,
    ActiveViolationTypeDef,
    CreateSecurityProfileRequestRequestTypeDef,
    DescribeSecurityProfileResponseTypeDef,
    UpdateSecurityProfileRequestRequestTypeDef,
    UpdateSecurityProfileResponseTypeDef,
    ValidateSecurityProfileBehaviorsRequestRequestTypeDef,
    ViolationEventTypeDef,
    CodeSigningTypeDef,
    CreateJobRequestRequestTypeDef,
    CreateJobTemplateRequestRequestTypeDef,
    DescribeJobTemplateResponseTypeDef,
    JobTypeDef,
    UpdateJobRequestRequestTypeDef,
    DescribeStreamResponseTypeDef,
    DescribeAuditMitigationActionsTaskResponseTypeDef,
    DetectMitigationActionsTaskSummaryTypeDef,
    ListAuditSuppressionsResponseTypeDef,
    AuditFindingTypeDef,
    TestAuthorizationResponseTypeDef,
    ActionTypeDef,
    ListActiveViolationsResponseTypeDef,
    ListViolationEventsResponseTypeDef,
    OTAUpdateFileTypeDef,
    DescribeJobResponseTypeDef,
    DescribeDetectMitigationActionsTaskResponseTypeDef,
    ListDetectMitigationActionsTasksResponseTypeDef,
    DescribeAuditFindingResponseTypeDef,
    ListAuditFindingsResponseTypeDef,
    TopicRulePayloadTypeDef,
    TopicRuleTypeDef,
    CreateOTAUpdateRequestRequestTypeDef,
    OTAUpdateInfoTypeDef,
    CreateTopicRuleRequestRequestTypeDef,
    ReplaceTopicRuleRequestRequestTypeDef,
    GetTopicRuleResponseTypeDef,
    GetOTAUpdateResponseTypeDef,
)


def get_structure() -> AbortCriteriaTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-iot` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
